@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
-$EXTRACTRC `find . -name \*.rc` >> rc.cpp
+$EXTRACTRC `find . -name \*.rc -o -name \*.ui` >> rc.cpp
 $XGETTEXT *.cpp -o $podir/choqok.pot
 rm -f rc.cpp
