@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -27,14 +27,20 @@
 #include <QProgressBar>
 #include <KMessageBox>
 #include "backend.h"
+#include <QTimer>
+
 AccountsWizard::AccountsWizard( QString alias, QWidget *parent )
         : KDialog( parent )
 {
     kDebug();
+    verifyTimer = 0;
     QWidget *dialog = new QWidget( this );
     ui.setupUi( dialog );
     dialog->setAttribute( Qt::WA_DeleteOnClose );
     this->setMainWidget( dialog );
+    slotServiceChanged( ui.kcfg_service->currentIndex() );
+    progress = 0;
+    connect( ui.kcfg_service, SIGNAL( currentIndexChanged(int) ), this, SLOT( slotServiceChanged(int) ) );
 
     if ( alias.isEmpty() ) {
         this->setCaption( i18n( "Add a new account" ) );
@@ -61,15 +67,22 @@ void AccountsWizard::loadAccount( QString &alias )
     ui.kcfg_password->setText( mAccount.password() );
     ui.kcfg_direction->setCurrentIndex(( mAccount.direction() == Qt::RightToLeft ) ? 1 : 0 );
     ui.kcfg_service->setCurrentIndex( mAccount.serviceType() );
+    ui.kcfg_homepage->setText( mAccount.homepage() );
 }
 
 void AccountsWizard::slotButtonClicked( int button )
 {
     kDebug();
     if ( button == KDialog::Ok ) {
+        QString home = ui.kcfg_homepage->text();
+        if( home.at( home.count() - 1 ) != '/' )
+            ui.kcfg_homepage->setText( home.append('/') );
         ///Show ProgressBar:
-        if ( progress )
+        if ( progress ) {
+            progress->hide();
+            progress->deleteLater();
             progress = 0L;
+        }
         progress = new QProgressBar( this );
         progress->setMinimum( 0 );
         progress->setMaximum( 0 );
@@ -78,13 +91,8 @@ void AccountsWizard::slotButtonClicked( int button )
             return;
         grid->addWidget( progress, grid->rowCount(), 0, grid->rowCount(), 2 );
         ///Check for account
-//         Account a;
-        mAccount.setServiceType( (Account::Service) ui.kcfg_service->currentIndex() );
-//         if ( ui.kcfg_service->currentIndex() == 1 ) {
-//             mAccount.setServiceType(Account::Identica);
-//         } else {
-//             mAccount.setServiceType(Account::Twitter);
-//         }
+        mAccount.setServiceType( (Account::Service) ui.kcfg_service->currentIndex(),
+                                 ui.kcfg_homepage->text() );
         mAccount.setUsername( ui.kcfg_username->text() );
         mAccount.setPassword( ui.kcfg_password->text() );
         mAccount.setDirection(( Qt::LayoutDirection )ui.kcfg_direction->currentIndex() );
@@ -94,6 +102,14 @@ void AccountsWizard::slotButtonClicked( int button )
         connect( b, SIGNAL( userVerified( Account* ) ), this, SLOT( slotUserVerified( Account* ) ) );
         connect( b, SIGNAL( sigError( const QString& ) ), this, SLOT( slotError( const QString& ) ) );
         b->verifyCredential();
+        if( verifyTimer ) {
+            verifyTimer->deleteLater();
+            verifyTimer = 0;
+        }
+        verifyTimer = new QTimer( this );
+        verifyTimer->setSingleShot( true );
+        connect ( verifyTimer, SIGNAL(timeout()), this, SLOT( handleVerifyTimeout() ) );
+        verifyTimer->start( 45000 );
     } else
         KDialog::slotButtonClicked( button );
 }
@@ -112,7 +128,11 @@ void AccountsWizard::slotUserVerified( Account * userAccount )
         mAccount = AccountManager::self()->addAccount( mAccount );
     }
     if ( mAccount.isError() ) {
+        if ( progress )
+            progress->deleteLater();
         kDebug() << "Cannot add or modify account with alias " << mAccount.alias();
+        KMessageBox::detailedError(this, i18n( "An error occurred when adding this account." ),
+                                    AccountManager::self()->lastError());
         return;
     }
 
@@ -127,9 +147,34 @@ void AccountsWizard::slotUserVerified( Account * userAccount )
 void AccountsWizard::slotError( const QString & errMsg )
 {
     kDebug();
-    KMessageBox::detailedError( this, i18n( "authentication failed, please check your credentials." ), errMsg );
-    if ( progress )
+    KMessageBox::detailedError( this, i18n( "Authentication failed, please check your credentials." ), errMsg );
+    if ( progress ) {
         progress->deleteLater();
+        progress = 0;
+    }
+    verifyTimer->stop();
+}
+
+void AccountsWizard::handleVerifyTimeout()
+{
+    KMessageBox::sorry(this, i18n( "Verification progress timed out. "
+                                   "Check your Internet connection and credentials then try again." ) , i18n( "Timeout" ) );
+    if ( progress ) {
+        progress->deleteLater();
+        progress = 0;
+    }
+    verifyTimer->stop();
+}
+
+void AccountsWizard::slotServiceChanged( int index )
+{
+    if( index == 2 ) {
+        ui.lblHomepage->setVisible( true );
+        ui.kcfg_homepage->setVisible( true );
+    } else {
+        ui.lblHomepage->setVisible( false );
+        ui.kcfg_homepage->setVisible( false );
+    }
 }
 
 #include "accountswizard.moc"
