@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -29,6 +29,7 @@
 #include <KUrl>
 #include "datacontainers.h"
 #include "account.h"
+#include <QDomDocument>
 class KJob;
 namespace KIO {
     class Job;
@@ -45,23 +46,24 @@ public:
 
     ~Backend();
 
-    void login();
-    void logout();
-
     void verifyCredential();
 
     QDateTime dateFromString( const QString &date );
     QString& latestErrorString();
 
+    static QString prepareStatus( QString status );
+    static QString shortenUrl(const QString &baseUrl);
+
 public slots:
-    void postNewStatus( const QString &statusMessage, uint replyToStatusId = 0 );
+    void postNewStatus( const QString &statusMessage, qulonglong replyToStatusId = 0 );
+    void twitPicCreatePost(const KUrl &picUrl, const QString &message);
     void sendDMessage( const QString &screenName, const QString &message );
-    void requestTimeLine( uint latestStatusId, TimeLineType type, int page = 0 );
-    void requestDMessages( uint latestStatusId, DMessageType type, int page = 0 );
-    void requestSingleStatus( uint statusId );
-    void requestFavorited( uint statusId, bool isFavorite );
-    void requestDestroy( uint statusId );
-    void requestDestroyDMessage( uint statusId );
+    void requestTimeLine( qulonglong latestStatusId, TimeLineType type, int page = 0 );
+    void requestDMessages( qulonglong latestStatusId, DMessageType type, int page = 0 );
+    void requestSingleStatus( qulonglong statusId );
+    void requestFavorited( qulonglong statusId, bool isFavorite );
+    void requestDestroy( qulonglong statusId );
+    void requestDestroyDMessage( qulonglong statusId );
     void abortPostNewStatus();
     void settingsChanged();
     void listFollowersScreenName();
@@ -79,13 +81,14 @@ signals:
     void outboxMessagesReceived( QList<Status> &msgList );
     void followersListed( const QStringList &followersList );
     void friendsListed( const QStringList &friendsList );
-    void singleStatusReceived( uint statusId, Status status );
+    void singleStatusReceived( Status status );
 
 protected slots:
     void slotListFollowersScreenName( KJob *job );
     void slotListFriendsScreenName( KJob *job );
     void slotPostNewStatusFinished( KJob *job );
     void slotPostNewStatusData(KIO::Job *job, const QByteArray &data);
+    void slotTwitPicCreatePost( KJob *job );
     void slotRequestTimelineFinished( KJob *job );
     void slotRequestFavoritedFinished( KJob *job );
     void slotRequestDestroyFinished( KJob *job );
@@ -98,21 +101,22 @@ protected slots:
 
 private:
     QStringList readUsersNameFromXml( const QByteArray &buffer );
-    QList<Status> * readTimeLineFromXml( const QByteArray &buffer );
-    QList<Status> * readDMessagesFromXml( const QByteArray &buffer );
-    Status readStatusFromXml( const QByteArray &buffer );
-    Status readDMessageFromXml( const QByteArray &buffer );
-    QString prepareStatus( QString status );
+    Status readStatusFromXml ( const QByteArray &buffer );
+    Status readStatusFromDomElement ( const QDomElement &root );
+    QList<Status> readTimelineFromXml ( const QByteArray &buffer );
+    Status readDMessageFromXml ( const QByteArray &buffer );
+    Status readDMessageFromDomElement ( const QDomElement &root );
+    QList<Status> readDMessagesFromXml ( const QByteArray &buffer );
+
     void setDefaultArgs( KUrl &url );
     void requestCurrentUser();
     void requestFollowers( int page = 1 );
     void requestFriends( int page = 1 );
-    QString shortenUrl(const QString &baseUrl);
 
     QString mLatestErrorString;
     QMap<KJob *, TimeLineType> mRequestTimelineMap;
     QMap<KJob *, DMessageType> mRequestDMessagesMap;
-    QMap<KJob *, uint> mRequestSingleStatusMap;
+    QMap<KJob *, qulonglong> mRequestSingleStatusMap;
 
     QMap<KJob *, QByteArray> mPostNewStatusBuffer;
     QMap<KJob *, QByteArray> mSendDMessageBuffer;
@@ -123,6 +127,7 @@ private:
     QStringList friendsList;
     short friendsPage;
     QString mScheme;
+    QList<KJob*> jobList;
 };
 
 #endif
