@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -24,8 +24,7 @@
 #ifndef CONSTANTS_H
 #define CONSTANTS_H
 
-#define APPNAME "choqok"
-
-#define MAX_STATUS_SIZE 140
+static const char APPNAME[] = "choqok";
+static const int MAX_STATUS_SIZE = 140;
 
 #endif
