@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -28,7 +28,7 @@
 
 struct User {
 public:
-    uint userId;
+    qulonglong userId;
     QString name;
     QString screenName;
     QString location;
@@ -36,18 +36,19 @@ public:
     QString profileImageUrl;
     QString homePageUrl;
     bool isProtected;
-    uint followersCount;
+    int followersCount;
+    int friendsCount;
 };
 
 struct Status {
 public:
     QDateTime creationDateTime;
-    uint statusId;
+    qulonglong statusId;
     QString content;
     QString source;
     bool isTruncated;
-    uint replyToStatusId;
-    uint replyToUserId;
+    qulonglong replyToStatusId;
+    qulonglong replyToUserId;
     bool isFavorited;
     QString replyToUserScreenName;
     User user;
