@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -22,7 +22,8 @@
 
 */
 
-#include "systrayicon.h"
+#include "mainwindow.h"
+#include "settings.h"
 #include "constants.h"
 #include <kuniqueapplication.h>
 #include <kaboutdata.h>
@@ -30,35 +31,33 @@
 #include <KDE/KLocale>
 
 static const char description[] =
-    I18N_NOOP( "KDE mono-blogging client,\n\
+    I18N_NOOP( "KDE micro-blogging client.\n\n\
 Currently supports <a href='http://twitter.com'>Twitter.com</a> and \
 <a href='http://identi.ca'>Identi.ca</a>" );
 
-static const char version[] = "0.4";
+static const char version[] = "0.6.1";
 
 int main( int argc, char **argv )
 {
-    KAboutData about( "choqok", 0, ki18n( "choqoK" ), version, ki18n( description ),
+    KAboutData about( "choqok", 0, ki18n( "Choqok" ), version, ki18n( description ),
                       KAboutData::License_GPL_V3, ki18n( "(C) 2008-2009 Mehrdad Momeny" ),
-                      KLocalizedString(), 0, "mehrdad.momeny@gmail.com" );
+                      KLocalizedString(), 0  );
     about.addAuthor( ki18n( "Mehrdad Momeny" ), ki18n( "Author and Core Developer" ),
-                     "mehrdad.momeny@gmail.com" );
+                     "mehrdad.momeny@gmail.com", "http://identi.ca/mtux" );
     about.addCredit( ki18n( "Roozbeh Shafiee" ), ki18n( "Icon designer" ), "roozbeh@roozbehonline.com" );
+    about.addCredit( ki18n( "Daniel Schaal" ), ki18n( "UI improvements" ), "daniel@foto-schaal.de");
+    about.addCredit( ki18n( "Stephen Henderson" ), ki18n( "Search API implementation" ), "hendersonsk@gmail.com");
     KCmdLineArgs::init( argc, argv, &about );
 
 //     KCmdLineOptions options;
 //     options.add("+[URL]", ki18n( "Document to open" ));
 //     KCmdLineArgs::addCmdLineOptions(options);
     KUniqueApplication app;
-
-    if ( KSystemTrayIcon::isSystemTrayAvailable() ) {
-        SysTrayIcon *sysIcon = new SysTrayIcon;
-        sysIcon->show();
-    } else {
-        MainWindow *mainWin = new MainWindow;
+    app.setQuitOnLastWindowClosed(false);
+    MainWindow *mainWin = new MainWindow;
+    mainWin->setAttribute(Qt::WA_DeleteOnClose, false);
+    if ( Settings::showMainWinOnStart() ) {
         mainWin->show();
     }
-
-
     return app.exec();
 }
