@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -30,15 +30,17 @@
 #include "ui_prefs_base.h"
 // #include "ui_accounts_base.h"
 #include "ui_appears_base.h"
+#include "searchwindow.h"
 
-#define TIMEOUT 5000
+static const int TIMEOUT = 5000;
 
 class QTimer;
-
+class QuickTwit;
+class SysTrayIcon;
 class KTabWidget;
 
 /**
- * This class serves as the main window for choqoK.  It handles the
+ * This class serves as the main window for Choqok.  It handles the
  * menus, toolbars, and status bars.
  *
  * @short Main window class
@@ -60,16 +62,20 @@ public:
     virtual ~MainWindow();
 
 signals:
-    void systemNotify( const QString &title, const QString &message, const QString &iconUrl );
     void updateTimeLines();
-    void sigSetUnread( int unread );
+    void updateSearchResults();
+    void updateSearchLimits();
+//     void sigSetUnread( int unread );
     void abortPostNewStatus();
     void setUnreadStatusesToReadState();
 
 public slots:
-    void toggleMainWindowVisibility();
+    void systemNotify( const QString &title, const QString &message, const QString &iconUrl );
+    void search(int type = 0, const QString &search = QString());
+
 protected slots:
     void optionsPreferences();
+//     void search();
     void settingsChanged();
     void notify( const QString &message, bool isPermanent = false );
     void quitApp();
@@ -77,16 +83,16 @@ protected slots:
     void showTimeLine();
 
 protected:
-//     void keyPressEvent ( QKeyEvent * e );
+    void hideEvent( QHideEvent * event );
     void checkUnreadStatuses( int numOfNewStatusesReciened );
-    bool queryClose();
+    QSize sizeHint() const;
 
 private:
     void setupActions();
+    void setupQuickTweet();
     void setDefaultDirection();
     void disableApp();
     void enableApp();
-    void loadConfigurations();
 
 private slots:
     void loadAccounts();
@@ -94,15 +100,20 @@ private slots:
     void removeAccountTimeLine( const QString &alias );
     void setTimeLineUpdatesEnabled( bool isEnabled );
     void setNotificationsEnabled( bool isEnabled );
+    void postQuickTwit( const QString &text=QString());
+    void toggleMainWindow();
+    void postNowListening();
 
 private:
     KTabWidget *mainWidget;
     QTimer *timelineTimer;
     Ui::prefs_base ui_prefs_base;
     Ui::appears_base ui_appears_base;
-    QString currentUsername;// used for undresanding of username changes!
+    QString currentUsername;// used for understanding username changes!
     int mPrevNotifyType;
     int mPrevUpdateInterval;
+    SysTrayIcon *sysIcon;
+    QuickTwit *quickWidget;
 };
 
 #endif
