@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -23,8 +23,6 @@
 */
 
 #include "quicktwit.h"
-#include <QKeyEvent>
-#include <KComboBox>
 #include "statustextedit.h"
 #include "backend.h"
 #include "datacontainers.h"
@@ -49,6 +47,9 @@ QuickTwit::QuickTwit( QWidget* parent ): KDialog( parent )
     this->resize( Settings::quickTweetSize() );
     txtStatus->setFocus( Qt::OtherFocusReason );
 
+    ui.checkAll->setChecked( Settings::quickTweetAll() );
+    checkAll( Settings::quickTweetAll() );
+
     this->setCaption( i18n( "Quick Tweet" ) );
     ui.lblCounter->setText( QString::number( MAX_STATUS_SIZE ) );
 
@@ -67,6 +68,7 @@ QuickTwit::QuickTwit( QWidget* parent ): KDialog( parent )
 
 QuickTwit::~QuickTwit()
 {
+    Settings::setQuickTweetAll(ui.checkAll->isChecked());
     Settings::setQuickTweetSize( this->size() );
     Settings::self()->writeConfig();
     kDebug();
@@ -97,14 +99,14 @@ void QuickTwit::slotPostNewStatusDone( bool isError )
     if ( isError ) {
         Backend * b = qobject_cast<Backend *>( sender() );
         QString name( APPNAME );
-        emit sigNotify( i18n( "Failed!" ), i18n( "Posting new status failed. %1",
+        emit sigNotify( i18n( "Failed." ), i18n( "Posting new status failed: %1",
                                                  b->latestErrorString() ), name );
     } else {
         txtStatus->clearContentsAndSetDirection( accountsList[ui.comboAccounts->currentIndex()].direction() );
         QString name( APPNAME );
-        emit sigNotify( i18n( "Success!" ), i18n( "New status posted successfully" ), name );
+        emit sigNotify( i18n( "Success." ), i18n( "New status posted successfully." ), name );
     }
-    this->close();
+//     this->close();
     sender()->deleteLater();
 }
 
@@ -172,4 +174,9 @@ void QuickTwit::checkAll( bool isAll )
     ui.comboAccounts->setEnabled( !isAll );
 }
 
+void QuickTwit::setText( const QString &text )
+{
+    this->txtStatus->setText(text);
+}
+
 #include "quicktwit.moc"
