@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -31,7 +31,7 @@
 class StatusTextEdit;
 class Backend;
 /**
-Widget for Quik twitting
+Widget for Quick twitting
 
     @author Mehrdad Momeny <mehrdad.momeny@gmail.com>
 */
@@ -50,6 +50,7 @@ public slots:
     void sltAccepted();
     void addAccount( const Account &account );
     void removeAccount( const QString &alias );
+    void setText( const QString &text );
 
 protected:
     void loadAccounts();
