@@ -1,5 +1,5 @@
 /*
-    This file is part of choqoK, the KDE mono-blogging client
+    This file is part of Choqok, the KDE micro-blogging client
 
     Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
@@ -29,11 +29,13 @@
 #include "accountmanager.h"
 #include <kdebug.h>
 #include <QTimer>
-#include <QScrollBar>
 #include <KDE/KLocale>
 #include <KDE/KMessageBox>
 #include <QProcess>
 #include <KDE/KNotification>
+#include <KFileDialog>
+#include <KUrl>
+#include <QKeyEvent>
 
 TimeLineWidget::TimeLineWidget( const Account &userAccount, QWidget* parent ) :
         QWidget( parent )
@@ -41,6 +43,7 @@ TimeLineWidget::TimeLineWidget( const Account &userAccount, QWidget* parent ) :
     kDebug();
     setupUi( this );
     mCurrentAccount = userAccount;
+    twitter = new Backend( &mCurrentAccount, this );
     latestHomeStatusId = latestReplyStatusId = 0;
 
     homeLayout->setDirection( QBoxLayout::TopToBottom );
@@ -51,6 +54,17 @@ TimeLineWidget::TimeLineWidget( const Account &userAccount, QWidget* parent ) :
     txtNewStatus->setObjectName( "txtNewStatus" );
     inputFrame->layout()->addWidget( txtNewStatus );
 
+    btnAttachMedia->setIcon(KIcon("mail-attachment"));
+    attachMediaFrame->hide();
+    if(mCurrentAccount.serviceType() == Account::Twitter) {
+        mediaToAttach.clear();
+        btnClearMedia->setIcon(KIcon("edit-clear"));
+        connect(btnAttachMedia, SIGNAL(clicked(bool)), SLOT(attachMedia()));
+        connect(btnClearMedia, SIGNAL(clicked(bool)), SLOT(clearMedia()));
+    } else {
+        btnAttachMedia->setEnabled(false);
+    }
+
 //     connect ( toggleArrow, SIGNAL ( clicked() ), this, SLOT ( toggleTwitFieldVisible() ) );
     connect( txtNewStatus, SIGNAL( charsLeft( int ) ), this, SLOT( checkNewStatusCharactersCount( int ) ) );
     connect( txtNewStatus, SIGNAL( returnPressed( QString& ) ), this, SLOT( postStatus( QString& ) ) );
@@ -69,13 +83,13 @@ void TimeLineWidget::aboutQuit()
     kDebug();
     AccountManager::self()->saveFriendsList( mCurrentAccount.alias(), friendsList );
     saveStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::HomeTimeLine ),
-                  listHomeStatus );
+                  listHomeStatus.values() );
     saveStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::ReplyTimeLine ),
-                  listReplyStatus );
+                  listReplyStatus.values() );
     saveStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::InboxTimeLine ),
-                  listInboxStatus );
+                  listInboxStatus.values() );
     saveStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::OutboxTimeLine ),
-                  listOutboxStatus );
+                  listOutboxStatus.values() );
     deleteLater();
 }
 
@@ -94,8 +108,6 @@ void TimeLineWidget::initObjects()
     lblCounter->setFont( counterF );
     checkNewStatusCharactersCount( 140 );
 
-    twitter = new Backend( &mCurrentAccount, this );
-
     connect( twitter, SIGNAL( homeTimeLineReceived( QList< Status >& ) ),
              this, SLOT( homeTimeLinesReceived( QList< Status >& ) ) );
     connect( twitter, SIGNAL( replyTimeLineReceived( QList< Status >& ) ),
@@ -104,12 +116,18 @@ void TimeLineWidget::initObjects()
              this, SLOT( directMessagesReceived( QList< Status >& ) ) );
     connect( twitter, SIGNAL( outboxMessagesReceived( QList< Status >& ) ),
              this, SLOT( outboxMessagesReceived( QList< Status >& ) ) );
-    connect( twitter, SIGNAL( sigPostNewStatusDone( bool ) ), this, SLOT( postingNewStatusDone( bool ) ) );
-    connect( twitter, SIGNAL( sigFavoritedDone( bool ) ), this, SLOT( requestFavoritedDone( bool ) ) );
-    connect( twitter, SIGNAL( sigDestroyDone( bool ) ), this, SLOT( requestDestroyDone( bool ) ) );
-    connect( twitter, SIGNAL( sigError( const QString& ) ), this, SLOT( error( const QString& ) ) );
-    connect( twitter, SIGNAL( friendsListed( const QStringList& ) ), this, SLOT( friendsListed( const QStringList& ) ) );
-    connect( twitter, SIGNAL( followersListed( const QStringList& ) ), this, SLOT( friendsListed( const QStringList& ) ) );
+    connect( twitter, SIGNAL( sigPostNewStatusDone( bool ) ),
+             this, SLOT( postingNewStatusDone( bool ) ) );
+    connect( twitter, SIGNAL( sigFavoritedDone( bool ) ),
+             this, SLOT( requestFavoritedDone( bool ) ) );
+    connect( twitter, SIGNAL( sigDestroyDone( bool ) ),
+             this, SLOT( requestDestroyDone( bool ) ) );
+    connect( twitter, SIGNAL( sigError( const QString& ) ),
+             this, SLOT( error( const QString& ) ) );
+    connect( twitter, SIGNAL( friendsListed( const QStringList& ) ),
+             this, SLOT( friendsListed( const QStringList& ) ) );
+    connect( twitter, SIGNAL( followersListed( const QStringList& ) ),
+             this, SLOT( friendsListed( const QStringList& ) ) );
 
     replyToStatusId = unreadStatusCount = unreadStatusInReply = unreadStatusInHome =
                                               unreadStatusInInbox = unreadStatusInOutbox = latestInboxStatusId =
@@ -134,11 +152,13 @@ void TimeLineWidget::checkNewStatusCharactersCount( int numOfChars )
     } else {
         lblCounter->setStyleSheet( "QLabel {color: green;}" );
     }
-//     kDebug()<<numOfChars;
+
     if ( numOfChars == 140 ) {
         txtNewStatus->setMaximumHeight( 28 );
+        lblCounter->setVisible(false);
     } else {
         txtNewStatus->setMaximumHeight( 80 );
+        lblCounter->setVisible(true);
     }
 
     lblCounter->setText( KGlobal::locale()->formatNumber( numOfChars, 0 ) );
@@ -150,6 +170,14 @@ void TimeLineWidget::settingsChanged()
     setDefaultDirection();
     twitter->settingsChanged();
     updateUi();
+    foreach(StatusWidget * s,listHomeStatus.values())
+      s->setUiStyle();
+    foreach(StatusWidget * s,listInboxStatus.values())
+      s->setUiStyle();
+    foreach(StatusWidget * s,listOutboxStatus.values())
+      s->setUiStyle();
+    foreach(StatusWidget * s,listReplyStatus.values())
+      s->setUiStyle();
 }
 
 void TimeLineWidget::updateTimeLines()
@@ -171,7 +199,7 @@ void TimeLineWidget::updateTimeLines()
 void TimeLineWidget::directMessagesReceived( QList< Status > & msgList )
 {
     kDebug();
-    emit notify( i18n( "Latest direct messages received!" ) );
+    emit notify( i18n( "Latest direct messages received." ) );
     int count = msgList.count();
 
     if ( count == 0 ) {
@@ -180,7 +208,7 @@ void TimeLineWidget::directMessagesReceived( QList< Status > & msgList )
         return;
     } else {
         addNewStatusesToUi( msgList, inboxLayout, &listInboxStatus, Backend::InboxTimeLine );
-        inboxScroll->verticalScrollBar()->setSliderPosition( 0 );
+//         inboxScroll->verticalScrollBar()->setSliderPosition( 0 );
         kDebug() << count << " Statuses received.";
         if ( !isStartMode ) {
             unreadStatusInInbox += count;
@@ -193,7 +221,7 @@ void TimeLineWidget::directMessagesReceived( QList< Status > & msgList )
 void TimeLineWidget::outboxMessagesReceived( QList< Status > & msgList )
 {
     kDebug();
-    emit notify( i18n( "Latest sent messages received!" ) );
+    emit notify( i18n( "Latest sent messages received." ) );
     int count = msgList.count();
 
     if ( count == 0 ) {
@@ -202,7 +230,7 @@ void TimeLineWidget::outboxMessagesReceived( QList< Status > & msgList )
         return;
     } else {
         addNewStatusesToUi( msgList, outboxLayout, &listOutboxStatus, Backend::OutboxTimeLine );
-        outboxScroll->verticalScrollBar()->setSliderPosition( 0 );
+//         outboxScroll->verticalScrollBar()->setSliderPosition( 0 );
 
         kDebug() << count << " Statuses received.";
 
@@ -217,7 +245,7 @@ void TimeLineWidget::outboxMessagesReceived( QList< Status > & msgList )
 void TimeLineWidget::homeTimeLinesReceived( QList< Status > & statusList )
 {
     kDebug();
-    emit notify( i18n( "Latest friends timeline received!" ) );
+    emit notify( i18n( "Latest friend timelines received." ) );
     int count = statusList.count();
 
     if ( count == 0 ) {
@@ -226,7 +254,7 @@ void TimeLineWidget::homeTimeLinesReceived( QList< Status > & statusList )
         return;
     } else {
         addNewStatusesToUi( statusList, homeLayout, &listHomeStatus );
-        homeScroll->verticalScrollBar()->setSliderPosition( 0 );
+//         homeScroll->verticalScrollBar()->setSliderPosition( 0 );
 
 //         int count = statusList.count();
         kDebug() << count << " Statuses received.";
@@ -242,7 +270,7 @@ void TimeLineWidget::homeTimeLinesReceived( QList< Status > & statusList )
 void TimeLineWidget::replyTimeLineReceived( QList< Status > & statusList )
 {
     kDebug();
-    emit notify( i18n( "Latest replies timeline received!" ) );
+    emit notify( i18n( "Latest reply timelines received." ) );
     int count = statusList.count();
     if ( count == 0 ) {
         kDebug() << "Status list is empty";
@@ -250,7 +278,7 @@ void TimeLineWidget::replyTimeLineReceived( QList< Status > & statusList )
         return;
     } else {
         addNewStatusesToUi( statusList, replyLayout, &listReplyStatus, Backend::ReplyTimeLine );
-        replyScroll->verticalScrollBar()->setSliderPosition( 0 );
+//         replyScroll->verticalScrollBar()->setSliderPosition( 0 );
 
 //         int count = statusList.count();
         kDebug() << count << " Statuses received.";
@@ -264,7 +292,7 @@ void TimeLineWidget::replyTimeLineReceived( QList< Status > & statusList )
 }
 
 void TimeLineWidget::addNewStatusesToUi( QList< Status > & statusList, QBoxLayout * layoutToAddStatuses,
-        QList<StatusWidget*> *list, Backend::TimeLineType type )
+        QMap<qulonglong, StatusWidget*> *list, Backend::TimeLineType type )
 {
     kDebug();
     bool allInOne = Settings::showAllNotifiesInOne();
@@ -272,27 +300,34 @@ void TimeLineWidget::addNewStatusesToUi( QList< Status > & statusList, QBoxLayou
     int numOfNewStatuses = statusList.count();
     QList<Status>::const_iterator it = statusList.constBegin();
     QList<Status>::const_iterator endIt = statusList.constEnd();
-    bool isThereIsAnyNewStatusToNotify = false;
-    if ( allInOne && Settings::notifyType() != 2 )
+    bool isThereAnyNewStatusToNotify = false;
+    if ( allInOne && Settings::notifyType() != SettingsBase::LibNotify )
         notifyStr = ( mCurrentAccount.direction() == Qt::RightToLeft ) ? "<div dir='rtl'>" : "<div dir='ltr'>";
     for ( ;it != endIt; ++it ) {
-        if ( it->replyToUserId == mCurrentAccount.userId() && type == Backend::HomeTimeLine ) {
-            --numOfNewStatuses;
-            --unreadStatusInHome;
-            continue;
+        if ( Settings::doNotShowRepliesOnHome() ) {
+            if ( it->replyToUserId == mCurrentAccount.userId() && type == Backend::HomeTimeLine ) {
+                --numOfNewStatuses;
+                --unreadStatusInHome;
+                continue;
+            }
         }
+        if(list->keys().contains(it->statusId)) 
+            continue;
+	
 
         StatusWidget *wt = new StatusWidget( &mCurrentAccount, this );
-
         wt->setAttribute( Qt::WA_DeleteOnClose );
         wt->setCurrentStatus( *it );
-        connect( wt, SIGNAL( sigReply( const QString&, uint ) ),
-                 this, SLOT( prepareReply( const QString&, uint ) ) );
-        connect( wt, SIGNAL( sigFavorite( uint, bool ) ),
-                 twitter, SLOT( requestFavorited( uint, bool ) ) );
-        connect( wt, SIGNAL( sigDestroy( uint ) ),
-                 this, SLOT( requestDestroy( uint ) ) );
-        list->append( wt );
+        connect( wt, SIGNAL( sigReply( const QString&, qulonglong, bool ) ),
+                 this, SLOT( prepareReply( const QString&, qulonglong, bool ) ) );
+        connect( wt, SIGNAL( sigFavorite( qulonglong, bool ) ),
+                 twitter, SLOT( requestFavorited( qulonglong, bool ) ) );
+        connect( wt, SIGNAL( sigDestroy( qulonglong ) ),
+                 this, SLOT( requestDestroy( qulonglong ) ) );
+        connect(wt,SIGNAL(sigSearch(int,QString)),this,SIGNAL(sigSearch(int,QString)));
+        connect(wt, SIGNAL(sigReTweet(const QString&)), this, SLOT(reTweet(const QString&)));
+
+        list->insert( it->statusId, wt );
         layoutToAddStatuses->insertWidget( 0, wt );
 
         if ( !isStartMode ) {
@@ -304,19 +339,18 @@ void TimeLineWidget::addNewStatusesToUi( QList< Status > & statusList, QBoxLayou
                     wt->setUnread( StatusWidget::WithoutNotify );
                 } else if ( allInOne ) {
                     notifyStr += "<b>" + it->user.screenName + " : </b>" + it->content + "<br/>";
-                    isThereIsAnyNewStatusToNotify = true;
+                    isThereAnyNewStatusToNotify = true;
                     wt->setUnread( StatusWidget::WithoutNotify );
                 } else {
                     wt->setUnread( StatusWidget::WithNotify );
                 }
             }
-
             listUnreadStatuses.append( wt );
         }
     }
-    if ( allInOne && Settings::notifyType() != 2 )
+    if ( allInOne && Settings::notifyType() != SettingsBase::LibNotify )
         notifyStr += "</div>";
-    uint latestId = statusList.last().statusId;
+    qulonglong latestId = statusList.last().statusId;
     if ( type == Backend::HomeTimeLine && latestId > latestHomeStatusId ) {
         kDebug() << "Latest home statusId sets to: " << latestId;
         latestHomeStatusId = latestId;
@@ -333,7 +367,7 @@ void TimeLineWidget::addNewStatusesToUi( QList< Status > & statusList, QBoxLayou
     if ( !isStartMode && type != Backend::OutboxTimeLine )
         checkUnreadStatuses( numOfNewStatuses );
 
-    if ( isThereIsAnyNewStatusToNotify ) {
+    if ( isThereAnyNewStatusToNotify ) {
         showNotify( i18n( "New statuses" ), notifyStr );
     }
 
@@ -348,10 +382,10 @@ void TimeLineWidget::abortPostNewStatus()
 
 void TimeLineWidget::setDefaultDirection()
 {
-    tabs->widget( 0 )->setLayoutDirection( mCurrentAccount.direction() );
-    tabs->widget( 1 )->setLayoutDirection( mCurrentAccount.direction() );
-    tabs->widget( 2 )->setLayoutDirection( mCurrentAccount.direction() );
-    tabs->widget( 3 )->setLayoutDirection( mCurrentAccount.direction() );
+//     tabs->widget( 0 )->setLayoutDirection( mCurrentAccount.direction() );
+//     tabs->widget( 1 )->setLayoutDirection( mCurrentAccount.direction() );
+//     tabs->widget( 2 )->setLayoutDirection( mCurrentAccount.direction() );
+//     tabs->widget( 3 )->setLayoutDirection( mCurrentAccount.direction() );
 //     tabs->widget ( 4 )->setLayoutDirection ( mCurrentAccount.direction() );
 
     txtNewStatus->setDefaultDirection( mCurrentAccount.direction() );
@@ -359,26 +393,33 @@ void TimeLineWidget::setDefaultDirection()
 
 void TimeLineWidget::error( const QString & errMsg )
 {
-    emit notify( i18n( "Failed, %1", errMsg ), true );
+    emit notify( i18n( "Failed: %1", errMsg ), true );
 }
 
 void TimeLineWidget::postStatus( QString & status )
 {
     kDebug();
 
-    if ( status.size() > MAX_STATUS_SIZE && status.indexOf( "http://" ) == -1 ) {
-        QString err = i18n( "Status text size is more than server limit size." );
-        error( err );
-        return;
+    if ( status.size() > MAX_STATUS_SIZE && status.indexOf( QRegExp( "https?://" ) ) == -1 ) {
+        QString err = i18n( "Message text size is greater than the server limit: \
+the server may truncate or drop it.\nAre you sure you want to post this message?" );
+        if(KMessageBox::warningContinueCancel( this, err ) == KMessageBox::Cancel)
+            return;
     }
     txtNewStatus->setEnabled( false );
-    if ( chkDMessage->isChecked() ) {
-        emit notify( i18n( "Sending direct message..." ), true );
-        twitter->sendDMessage( comboFriendList->currentText(), status );
-        chkDMessage->setChecked( false );
+    if( mediaToAttach.isEmpty() ) {
+        if ( chkDMessage->isChecked() ) {
+            emit notify( i18n( "Sending direct message...." ), true );
+            twitter->sendDMessage( comboFriendList->currentText(), status );
+            chkDMessage->setChecked( false );
+        } else {
+            emit notify( i18n( "Posting new status...." ), true );
+            twitter->postNewStatus( status, replyToStatusId );
+        }
     } else {
-        emit notify( i18n( "Posting new status..." ), true );
-        twitter->postNewStatus( status, replyToStatusId );
+        emit notify( i18n( "Posting new status...." ), true );
+        twitter->twitPicCreatePost( mediaToAttach, status );
+        mediaToAttach.clear();
     }
 }
 
@@ -387,20 +428,27 @@ void TimeLineWidget::postingNewStatusDone( bool isError )
     kDebug();
 //     emit sigStatusUpdated( isError );
     if ( !isError ) {
+        clearMedia();
         txtNewStatus->clearContentsAndSetDirection( mCurrentAccount.direction() );
         QString successMsg = i18n( "New status posted successfully" );
-        emit systemNotify( i18n( "Success!" ), successMsg, APPNAME );
+        emit systemNotify( i18n( "Success." ), successMsg, APPNAME );
         notify( successMsg );
         replyToStatusId = 0;
+        lblCounter->setPixmap(KIcon("dialog-ok").pixmap(22));
+        twitter->requestTimeLine(latestHomeStatusId, Backend::HomeTimeLine);
     } else {
+        lblCounter->setPixmap(KIcon("dialog-cancel").pixmap(22));
         error( twitter->latestErrorString() );
     }
+    QTimer::singleShot( 3000, this, SLOT( revertCounterLabelShape() ) );
+    lblCounter->show();
+    lblCounter->setText(QString());
     txtNewStatus->setFocus( Qt::OtherFocusReason );
     txtNewStatus->setEnabled( true );
 
 }
 
-bool TimeLineWidget::saveStatuses( QString fileName, QList<StatusWidget*> &list )
+bool TimeLineWidget::saveStatuses( QString fileName, QList<StatusWidget*> list )
 {
     kDebug();
     KConfig statusesBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
@@ -435,6 +483,10 @@ bool TimeLineWidget::saveStatuses( QString fileName, QList<StatusWidget*> &list
         grp.writeEntry( "profile_image_url", list[i]->currentStatus().user.profileImageUrl );
         grp.writeEntry( "description" , list[i]->currentStatus().user.description );
         grp.writeEntry( "isDMessage" , list[i]->currentStatus().isDMessage );
+        grp.writeEntry( "location" , list[i]->currentStatus().user.location );
+        grp.writeEntry( "url" , list[i]->currentStatus().user.homePageUrl );
+        grp.writeEntry( "followers_count" , list[i]->currentStatus().user.followersCount );
+        grp.writeEntry( "friends_count" , list[i]->currentStatus().user.friendsCount );
     }
 
     statusesBackup.sync();
@@ -456,38 +508,42 @@ QList< Status > TimeLineWidget::loadStatuses( QString fileName )
         KConfigGroup grp( &statusesBackup, groupList[i] );
         Status st;
         st.creationDateTime = grp.readEntry( "created_at", QDateTime::currentDateTime() );
-        st.statusId = grp.readEntry( "id", ( uint ) 0 );
+        st.statusId = grp.readEntry( "id", ( qulonglong ) 0 );
         st.content = grp.readEntry( "text", QString() );
         st.source = grp.readEntry( "source", QString() );
         st.isTruncated = grp.readEntry( "truncated", false );
-        st.replyToStatusId = grp.readEntry( "in_reply_to_status_id", ( uint ) 0 );
-        st.replyToUserId = grp.readEntry( "in_reply_to_user_id", ( uint ) 0 );
+        st.replyToStatusId = grp.readEntry( "in_reply_to_status_id", ( qulonglong ) 0 );
+        st.replyToUserId = grp.readEntry( "in_reply_to_user_id", ( qulonglong ) 0 );
         st.isFavorited = grp.readEntry( "favorited", false );
         st.replyToUserScreenName = grp.readEntry( "in_reply_to_screen_name", QString() );
-        st.user.userId = grp.readEntry( "userId", ( uint ) 0 );
+        st.user.userId = grp.readEntry( "userId", ( qulonglong ) 0 );
         st.user.screenName = grp.readEntry( "screen_name", QString() );
         st.user.name = grp.readEntry( "name", QString() );
         st.user.profileImageUrl = grp.readEntry( "profile_image_url", QString() );
         st.user.description = grp.readEntry( "description" , QString() );
         st.isDMessage = grp.readEntry( "isDMessage" , false );
+        st.user.location = grp.readEntry("location", QString());
+        st.user.homePageUrl = grp.readEntry("url", QString());
+        st.user.followersCount = grp.readEntry("followers_count", 0);
+        st.user.friendsCount = grp.readEntry("friends_count", 0);
 
         //Sorting The new statuses:
-        int i = 0;
+        int j = 0;
         int count = list.count();
-        while (( i < count ) && ( st.statusId > list[ i ].statusId ) ) {
-            ++i;
+        while (( j < count ) && ( st.statusId > list[ j ].statusId ) ) {
+            ++j;
         }
-        list.insert( i, st );
+        list.insert( j, st );
     }
 
     return list;
 }
 
-void TimeLineWidget::prepareReply( const QString &userName, uint statusId )
+void TimeLineWidget::prepareReply( const QString &userName, qulonglong statusId, bool dMsg )
 {
     kDebug();
     emit showMe();
-    if ( qobject_cast<StatusWidget*> ( sender() )->currentStatus().isDMessage ) {
+    if ( dMsg ) {
         chkDMessage->setChecked( true );
         comboFriendList->setCurrentItem( userName, true, 0 );
     } else {
@@ -500,39 +556,31 @@ void TimeLineWidget::prepareReply( const QString &userName, uint statusId )
     txtNewStatus->setFocus( Qt::OtherFocusReason );
 }
 
-void TimeLineWidget::updateStatusList( QList<StatusWidget*> *list )
+void TimeLineWidget::updateStatusList( QMap<qulonglong, StatusWidget*> *list )
 {
     kDebug();
     int toBeDelete = list->count() - Settings::countOfStatusesOnMain();
 
     if ( toBeDelete > 0 ) {
-        for ( int i = 0; i < toBeDelete; ++i ) {
-            StatusWidget* wt = list->at( i );
-
-            if ( !wt->isReaded() )
+        QMap<qulonglong, StatusWidget*>::const_iterator it = list->constBegin();
+        QMap<qulonglong, StatusWidget*>::const_iterator endIt = list->constEnd();
+        for ( ; it != endIt && toBeDelete > 0; ++it ) {
+            StatusWidget* wt = it.value();
+            if( !wt )
+                continue;
+            if ( !wt->isRead() )
                 break;
-
-            list->removeAt( i );
-
-            --i;
-
-            --toBeDelete;
-
             wt->close();
+            list->remove( it.key() );
+            --toBeDelete;
         }
     }
 }
 
-void TimeLineWidget::clearTimeLineList( QList< StatusWidget * > * list )
+void TimeLineWidget::clearTimeLineList( QMap<qulonglong, StatusWidget * > * list )
 {
     kDebug();
-    int count = list->count();
-
-    for ( int i = 0; i < count; ++i ) {
-        StatusWidget* wt = list->first();
-        list->removeFirst();
-        wt->close();
-    }
+    qDeleteAll(*list);
 }
 
 void TimeLineWidget::loadConfigurations()
@@ -548,21 +596,30 @@ void TimeLineWidget::loadConfigurations()
 
     isStartMode = true;
 
-    QList< Status > lstHome = loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::HomeTimeLine ) );
+    QList< Status > lstHome =
+        loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(),
+                                                                    Backend::HomeTimeLine ) );
     if ( lstHome.count() > 0 )
-        addNewStatusesToUi( lstHome, homeLayout, &listHomeStatus );
+        homeTimeLinesReceived( lstHome );
 
-    QList< Status > lstReply = loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::ReplyTimeLine ) );
+    QList< Status > lstReply =
+        loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(),
+                                                                    Backend::ReplyTimeLine ) );
     if ( lstReply.count() > 0 )
-        addNewStatusesToUi( lstReply, replyLayout, &listReplyStatus, Backend::ReplyTimeLine );
+        replyTimeLineReceived( lstReply );
 
-    QList< Status > lstInbox = loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::InboxTimeLine ) );
+    QList< Status > lstInbox =
+        loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(),
+                                                                    Backend::InboxTimeLine ) );
     if ( lstInbox.count() > 0 )
-        addNewStatusesToUi( lstInbox, inboxLayout, &listInboxStatus, Backend::InboxTimeLine );
+        directMessagesReceived( lstInbox );
 
-    QList< Status > lstOutbox = loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(), Backend::OutboxTimeLine ) );
+    QList< Status > lstOutbox =
+        loadStatuses( AccountManager::generateStatusBackupFileName( mCurrentAccount.alias(),
+                                                                    Backend::OutboxTimeLine ) );
     if ( lstOutbox.count() > 0 )
-        addNewStatusesToUi( lstOutbox, outboxLayout, &listOutboxStatus, Backend::OutboxTimeLine );
+        outboxMessagesReceived( lstOutbox );
+
 }
 
 void TimeLineWidget::checkUnreadStatuses( int numOfNewStatusesReciened )
@@ -580,10 +637,10 @@ void TimeLineWidget::checkUnreadStatuses( int numOfNewStatusesReciened )
 void TimeLineWidget::setUnreadStatusesToReadState()
 {
     kDebug();
-    tabs->setTabText( 0, i18n( "Home" ) );
-    tabs->setTabText( 1, i18n( "Reply" ) );
-    tabs->setTabText( 2, i18n( "Inbox" ) );
-    tabs->setTabText( 3, i18n( "Outbox" ) );
+    tabs->setTabText( 0, i18nc( "@title:tab", "Home" ) );
+    tabs->setTabText( 1, i18nc( "@title:tab", "Reply" ) );
+    tabs->setTabText( 2, i18nc( "@title:tab", "Inbox" ) );
+    tabs->setTabText( 3, i18nc( "@title:tab", "Outbox" ) );
     int count = listUnreadStatuses.count();
 
     for ( int i = 0;i < count; ++i ) {
@@ -591,6 +648,11 @@ void TimeLineWidget::setUnreadStatusesToReadState()
     }
 
     listUnreadStatuses.clear();
+//     if(unreadStatusCount) {
+//       QString s = qApp->styleSheet();
+//       qApp->setStyleSheet(s);
+//     }
+//     qApp->setStyleSheet( StatusWidget::getColoredStyle() );
 
     emit sigSetUnread( -unreadStatusCount );
     emit sigSetUnreadOnMainWin( 0 );
@@ -610,9 +672,9 @@ void TimeLineWidget::requestDestroyDone( bool isError )
     toBeDestroied->close();
 }
 
-void TimeLineWidget::requestDestroy( uint statusId )
+void TimeLineWidget::requestDestroy( qulonglong statusId )
 {
-    if ( KMessageBox::warningYesNo( this, i18n( "Are you sure of destroying this status?" ) ) == KMessageBox::Yes ) {
+    if ( KMessageBox::warningYesNo( this, i18n( "Are you sure you wish to destroy this status?" ) ) == KMessageBox::Yes ) {
         toBeDestroied = qobject_cast<StatusWidget*> ( sender() );
         if ( toBeDestroied->currentStatus().isDMessage ) {
             twitter->requestDestroyDMessage( statusId );
@@ -649,7 +711,7 @@ void TimeLineWidget::reloadFriendsList()
 {
     kDebug();
     friendsList.clear();
-    comboFriendList->setCurrentItem( i18n("Please wait..."), true, 0);
+    comboFriendList->setCurrentItem( i18n("Please wait...."), true, 0);
     twitter->listFollowersScreenName();
     twitter->listFriendsScreenName();
 }
@@ -671,13 +733,13 @@ void TimeLineWidget::friendsListed( const QStringList & list )
 
 void TimeLineWidget::showNotify( const QString &title, const QString &message )
 {
-    if ( Settings::notifyType() == 1 ) {//KNotify
+    if ( Settings::notifyType() == SettingsBase::KNotify ) {//KNotify
         KNotification *notif = new KNotification( "new-status-arrived", parentWidget() );
         notif->setText( message );
         notif->setFlags( KNotification::RaiseWidgetOnActivation | KNotification::Persistent );
         notif->sendEvent();
         QTimer::singleShot( Settings::notifyInterval()*1000, notif, SLOT( close() ) );
-    } else if ( Settings::notifyType() == 2 ) {//Libnotify!
+    } else if ( Settings::notifyType() == SettingsBase::LibNotify ) {//Libnotify!
         QString msg = message;
         msg = msg.replace( "<br/>", "\n" );
         QString libnotifyCmd = QString( "notify-send -t " ) + QString::number( Settings::notifyInterval() * 1000 )
@@ -706,4 +768,53 @@ void TimeLineWidget::updateUi()
     }
 }
 
+void TimeLineWidget::revertCounterLabelShape()
+{
+    lblCounter->setPixmap( QPixmap() );
+    checkNewStatusCharactersCount( txtNewStatus->countOfRemainsChar() );
+}
+
+Backend* TimeLineWidget::getBackend()
+{
+    return twitter;
+}
+
+void TimeLineWidget::reTweet( const QString &text )
+{
+    replyToStatusId = 0;
+    txtNewStatus->setText( text );
+    txtNewStatus->setFocus(Qt::OtherFocusReason);
+}
+
+void TimeLineWidget::attachMedia()
+{
+    kDebug();
+    QString mediaPath = KFileDialog::getOpenFileName( KUrl("kfiledialog:///image?global"),
+                                                      "image/png image/jpeg image/gif", this,
+                                                      i18n("Select media to attach"));
+    if( !mediaPath.isEmpty() ) {
+        mediaToAttach.setPath(mediaPath);
+        lblMediaName->setText( mediaToAttach.fileName() );
+        lblMediaName->setToolTip(mediaPath);
+        attachMediaFrame->show();
+    }
+    txtNewStatus->setFocus(Qt::OtherFocusReason);
+}
+
+void TimeLineWidget::clearMedia()
+{
+    lblMediaName->clear();
+    mediaToAttach.clear();
+    attachMediaFrame->hide();
+}
+
+void TimeLineWidget::keyPressEvent( QKeyEvent *event )
+{
+    if(event->key() == Qt::Key_Escape){
+        twitter->abortPostNewStatus();
+        txtNewStatus->setEnabled(true);
+        txtNewStatus->setFocus();
+    }
+}
+
 #include "timelinewidget.moc"
